// test program for modified AKIZUKI PIC18F2550 board 
// with Microchip's HID bootloader  

#include <p18f2550.h>

volatile unsigned onoff;

//----------------------------------------------------------

#pragma code reset_vector=0x1000
extern void _startup(void);
void remapped_reset(void) { _asm goto _startup _endasm}

#pragma code high_isr_vector=0x1008
void high_isr();
void remapped_high_isr(void) { _asm goto high_isr _endasm }

#pragma code low_isr_vector=0x1018
void low_isr();
void remapped_low_isr(void) { _asm goto low_isr _endasm }

#pragma code

#pragma interrupt high_isr
void high_isr() {
  onoff=~onoff;          // toggle onoff
  INTCON=0x0fb&INTCON;   // clear Timer0 interrupt flag bit
}

#pragma interruptlow low_isr
void low_isr() {
  // something to do here
}

//----------------------------------------------------------

void main(void) {

  onoff=1;
  TRISCbits.TRISC6=1;    // RC6 is input (program jumper pin)
  TRISCbits.TRISC0=0;    // RC0 is output (LED)

  INTCON =0x00;          // disable all interrupt        
  INTCON2=0x84;          // set Timer0 as high priority interrupt
  RCON   =0x80|RCON;     // enable interrupt priority level
  TMR0H  =0;             // clear Timer0 high byte 
  TMR0L  =0;             // clear Timer0 low byte
  T0CON  =0x82;          // set up timer0 
  INTCON =0x0a0|INTCON;  // enable Timer0 interrupt

  while(1) {
    if (PORTCbits.RC6==0) {      // if program jumper short
      PORTCbits.RC0=onoff&0x01;  // blink LED
    } else {                     // else
      PORTCbits.RC0=0;           // turn off LED
    }
  }

}
